"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const os = require("os");
const path = require("path");
const stripAnsi = require("strip-ansi");
const _1 = require("../");
const helper_1 = require("./helper");
describe('writeDeclarationFile()', () => {
    let pkgDir;
    const writesDeclarationFile = () => {
        it('writes a declaration file to the given package dir', async () => {
            const expectedFilename = path.resolve(pkgDir, 'index.d.ts');
            await fs.remove(expectedFilename);
            const actualFilename = await _1.writeDeclarationFile(pkgDir);
            expect(actualFilename).toBe(expectedFilename);
            const fileContents = await fs.readFile(actualFilename);
            expect(fileContents.toString()).toMatchSnapshot();
        });
    };
    describe('with an absolute package dir', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('export-from-js');
        });
        writesDeclarationFile();
    });
    describe('with a relative package dir', () => {
        beforeEach(() => {
            pkgDir = path.join('src', '__tests__', '__fixtures__', 'export-from-js');
        });
        writesDeclarationFile();
    });
    describe('with module export-from-js and a custom outDir', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('export-from-js');
        });
        it('writes the declaration file export-from-js.d.ts into the given directory', async () => {
            const outDir = await fs.mkdtemp(path.join(os.tmpdir(), 'drm-test-'));
            const expectedFilename = path.join(outDir, 'export-from-js.d.ts');
            const actualFilename = await _1.writeDeclarationFile(pkgDir, { outDir });
            expect(actualFilename).toBe(expectedFilename);
            const fileContents = await fs.readFile(actualFilename);
            expect(fileContents.toString()).toMatchSnapshot();
            return fs.remove(outDir);
        });
    });
});
describe('cli()', () => {
    let pkgDir;
    let processExitMock;
    let consoleErrorMock;
    beforeAll(() => {
        processExitMock = jest.spyOn(process, 'exit');
        processExitMock.mockImplementation(jest.fn());
        consoleErrorMock = jest.spyOn(console, 'error');
        consoleErrorMock.mockImplementation(jest.fn());
    });
    afterAll(() => {
        processExitMock.mockRestore();
        consoleErrorMock.mockRestore();
    });
    describe('with a valid module', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('export-from-js');
        });
        it('resolves', async () => {
            const promise = _1.cli(pkgDir);
            return expect(promise).resolves.toBeUndefined();
        });
    });
    describe('when no package.json can be found', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('export-from-jsx');
        });
        it('exits and logs an error message', async () => {
            await _1.cli(pkgDir);
            expect(processExitMock).toHaveBeenCalledWith(1);
            expect(consoleErrorMock).toHaveBeenCalledTimes(2);
        });
    });
    describe('when a module has invalid syntax', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('invalid-syntax');
        });
        it('exits and logs an error message with a code frame', async () => {
            await _1.cli(pkgDir);
            expect(processExitMock).toHaveBeenCalledWith(1);
            expect(consoleErrorMock).toHaveBeenCalledTimes(3);
            expect(stripAnsi(consoleErrorMock.mock.calls[2][0])).toBe(`   8 | \n   9 |   render() {
> 10 |     return <div>{this.props.foo,}</div>;
     |                                 ^
  11 |   }
  12 | }
  13 | `);
        });
    });
    describe('with module export-from-js and a custom outDir', () => {
        beforeEach(() => {
            pkgDir = helper_1.getModuleDirname('export-from-js');
        });
        it('writes the declaration file export-from-js.d.ts into the given directory', async () => {
            const outDir = await fs.mkdtemp(path.join(os.tmpdir(), 'drm-test-'));
            const filename = path.join(outDir, 'export-from-js.d.ts');
            await _1.cli(pkgDir, { outDir });
            const fileContents = await fs.readFile(filename);
            expect(fileContents.toString()).toMatchSnapshot();
            return fs.remove(outDir);
        });
    });
});
//# sourceMappingURL=index.test.js.map